<img src="https://i.ibb.co/ZTq7C5V/260.png" align="center" style="object-fit: scale-down"/>

<p align="center" style="font-size: 25">This module will help you encrypt a python file using base64 encoding</p>

<h3 align="center">To encrypt a file you can enter the command 'python3 -m pytobase encode file.py' or add 'from pytobase import encode' to the beginning of the file</h3>

<h4 align="center" style="font-size: 15">ATTENTION!!! Be sure to save a backup copy of the file somewhere else, as the original file will be overwritten!</h4>

<h5 style="font-size: 10">By Zailox</h5>